import { type CSSProperties, defineComponent } from 'vue'
import { css, cx } from '@emotion/css'
import { Space } from 'tdesign-vue-next'

const prefixCls = 'tdesign-app-toolbar'
const appToolbarStyled = css({
  [`&.${prefixCls}`]: {
    height: '60px',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    borderBottom: `1px solid #f0f0f0`,
    padding: '0px 8px',
    boxSizing: 'border-box',
    [`&-heading`]: {
      display: 'flex',
      justifyContent: 'space-between',
      alignItems: 'center',
      width: '100%',
      gap: '8px',

      [`&-left`]: {
        ['.ant-avatar']: {
          display: 'flex'
        },
        [`&-title`]: {
          color: '#000000d9',
          fontWeight: 600,
          fontSize: '20px',
          lineHeight: '32px',
          overflow: 'hidden',
          whiteSpace: 'nowrap',
          textOverflow: 'ellipsis'
        }
      },
      [`&-right`]: {},
      [`.ant-menu-horizontal`]: {
        flex: '1 auto',
        height: '60px',
        backgroundColor: 'inherit',
        li: {
          display: 'flex',
          alignItems: 'center'
        }
      }
    }
  }
})

export type AppToolbarProps = {
  className?: string
  style?: CSSProperties
}

export default defineComponent({
  name: 'AppToolbar',
  props: {
    className: {
      type: String,
      default: ''
    },
    style: {
      type: Object,
      default: () => ({})
    }
  },
  components: {
    Space
  },
  setup(props: AppToolbarProps, { slots }) {
    return () => (
      <div class={cx(appToolbarStyled, prefixCls)} style={props.style}>
        <div class={`${prefixCls}-heading`}>
          <div class={`${prefixCls}-heading-left`}></div>
          <div class={`${prefixCls}-heading-right`}>
            <Space>{slots.extra?.()}</Space>
          </div>
          <div>1231231</div>
        </div>
      </div>
    )
  }
})
