import { type CSSProperties, defineComponent, type PropType } from 'vue'
import { css, cx } from '@emotion/css'

const prefixCls = 'td-tdesign-layout-item'
const layoutItemStyled = css({
  [`&.${prefixCls}`]: {
    display: 'flex',
    [`&-auto`]: {
      boxSizing: 'border-box',
      flex: '1 auto',
      minWidth: 0,
      minHeight: 0
    }
  }
})

export type LayoutItemProps = {
  className?: string | undefined
  style?: CSSProperties
  auto?: boolean
}

export default defineComponent({
  name: 'TdLayoutItem',
  props: {
    className: {
      type: String,
      default: ''
    },
    style: {
      type: Object,
      default: () => ({})
    },
    auto: {
      type: Boolean as PropType<boolean>,
      default: false
    }
  },
  setup(props: LayoutItemProps, { slots }) {
    return () => (
      <div
        class={[cx(layoutItemStyled, prefixCls), { [`${prefixCls}-auto`]: props.auto }]}
        style={props.style}
      >
        {slots.default?.()}
      </div>
    )
  }
})
