import { type CSSProperties, defineComponent, type PropType } from 'vue'
import { css, cx } from '@emotion/css'

const prefixCls = 'td-tdesign-layout'
const layoutStyled = css({
  [`&.${prefixCls}`]: {
    minWidth: 0,
    minHeight: 0,
    height: '100%',
    width: '100%',
    display: 'flex',
    boxSizing: 'border-box',
    [`&-vertical`]: {
      flexDirection: 'column',
      [`>.${prefixCls}-item-auto`]: {
        minWidth: 0,
        minHeight: 0
      }
    },
    [`&-horizontal`]: {
      flexDirection: 'row',
      [`>.${prefixCls}-item-auto`]: {
        minWidth: 0,
        minHeight: 0
      }
    }
  }
})

export type LayoutProps = {
  direction?: 'vertical' | 'horizontal'
}

export default defineComponent({
  name: 'TdLayout',
  props: {
    className: {
      type: String as PropType<string>
    },
    style: {
      type: Object as PropType<CSSProperties>
    },
    direction: {
      type: String as PropType<LayoutProps['direction']>,
      default: 'horizontal'
    }
  },
  setup(props: LayoutProps, { slots }) {
    return () => (
      <div class={cx(layoutStyled, prefixCls, `${prefixCls}-${props.direction}`)}>
        {slots.default?.()}
      </div>
    )
  }
})
